<?php # -*- coding: utf-8 -*-
/**
 * Class Mlp_Db_Languages_Schema
 *
 * Specific data for the language table.
 *
 * @version 2014.01.29
 * @author  Inpsyde GmbH, toscho
 * @license GPL
 */
class Mlp_Db_Languages_Schema implements Mlp_Db_Schema_Interface
{

	/**
	 * Get table name.
	 *
	 * @return string
	 */
	public function get_table_name()
	{
		return $GLOBALS[ 'wpdb' ]->base_prefix . 'mlp_languages';
	}

	/**
	 * Get the table columns.
	 *
	 * @return array
	 */
	public function get_schema()
	{

		return array (
			'ID'           => 'bigint unsigned NOT NULL auto_increment',
			'english_name' => 'tinytext',
			'native_name'  => 'tinytext',
			'custom_name'  => 'tinytext',
			// BOOL was added in MyQL 5.0.3, but WordPress requires just 5.0.0
			'is_rtl'       => 'tinyint(1) unsigned DEFAULT 0',
			// Could be de-DE-1901 or something more sophisticated
			'iso_639_1'    => 'VARCHAR(20)',
			'iso_639_2'    => 'VARCHAR(20)',
			'wp_locale'    => 'tinytext',
			// Same as iso_639_1, but with '-', not '_'
			'http_name'    => 'VARCHAR(20)',
			'priority'     => 'tinyint(1) unsigned DEFAULT 10',
		);
	}

	/**
	 * Get the primary key.
	 *
	 * @return string
	 */
	public function get_primary_key()
	{
		return 'ID';
	}

	/**
	 * Get keys which should be ignored when rows are inserted.
	 *
	 * @return array
	 */
	public function get_autofilled_keys()
	{
		return array ( 'ID' );
	}

	/**
	 * @todo Useful indexes
	 * (non-PHPdoc)
	 * @see  Mlp_Db_Schema_Interface::get_index_sql()
	 */
	public function get_index_sql()
	{
	}

	/**
	 * Languages for db table installation. Will not be used later.
	 *
	 * @see Mlp_Db_Schema_Interface::get_default_content()
	 *
	 * @return string
	 */
	public function get_default_content()
	{
		$out    = array ();
		$fields = array (
			'aa'    => array (
				'english_name' => 'Afar',
				'native_name'  => 'Afaraf',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'aa',
				'iso_639_2'    => 'aar',
				'wp_locale'    => '',
				'http_name'    => 'aa',
				'priority'     => 1,
			),
			'ae'    => array (
				'english_name' => 'Avestan',
				'native_name'  => 'avesta',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ae',
				'iso_639_2'    => 'ave',
				'wp_locale'    => '',
				'http_name'    => 'ae',
				'priority'     => 1,
			),
			'af'    => array (
				'english_name' => 'Afrikaans',
				'native_name'  => 'Afrikaans',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'af',
				'iso_639_2'    => 'afr',
				'wp_locale'    => 'af',
				'http_name'    => 'af-ZA',
				'priority'     => 1,
			),
			'ak'    => array (
				'english_name' => 'Akan',
				'native_name'  => 'Akan',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ak',
				'iso_639_2'    => 'aka',
				'wp_locale'    => 'ak',
				'http_name'    => 'ak',
				'priority'     => 1,
			),
			'am'    => array (
				'english_name' => 'Amharic',
				'native_name'  => 'አማርኛ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'am',
				'iso_639_2'    => 'amh',
				'wp_locale'    => '',
				'http_name'    => 'am',
				'priority'     => 1,
			),
			'an'    => array (
				'english_name' => 'Aragonese',
				'native_name'  => 'Aragonés',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'an',
				'iso_639_2'    => 'arg',
				'wp_locale'    => '',
				'http_name'    => 'an',
				'priority'     => 1,
			),
			'ar'    => array (
				'english_name' => 'Arabic',
				'native_name'  => 'العربية',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'ar',
				'iso_639_2'    => 'ara',
				'wp_locale'    => 'ar',
				'http_name'    => 'ar-AR',
				'priority'     => 1,
			),
			'as'    => array (
				'english_name' => 'Assamese',
				'native_name'  => 'অসমীয়া',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'as',
				'iso_639_2'    => 'asm',
				'wp_locale'    => 'as',
				'http_name'    => 'asm',
				'priority'     => 1,
			),
			'ast'   => array (
				'english_name' => 'Asturian',
				'native_name'  => 'Asturianu',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => 'ast',
				'wp_locale'    => 'ast',
				'http_name'    => 'ast',
				'priority'     => 1,
			),
			'av'    => array (
				'english_name' => 'Avaric',
				'native_name'  => 'авар мацӀ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'av',
				'iso_639_2'    => 'ava',
				'wp_locale'    => '',
				'http_name'    => 'av',
				'priority'     => 1,
			),
			'ay'    => array (
				'english_name' => 'Aymara',
				'native_name'  => 'aymar aru',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ay',
				'iso_639_2'    => 'aym',
				'wp_locale'    => '',
				'http_name'    => 'ay',
				'priority'     => 1,
			),
			'az'    => array (
				'english_name' => 'Azerbaijani',
				'native_name'  => 'Azərbaycan dili',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'az',
				'iso_639_2'    => 'aze',
				'wp_locale'    => 'az',
				'http_name'    => 'az-AZ',
				'priority'     => 1,
			),
			'azb'   => array (
				'english_name' => 'South Azerbaijani',
				'native_name'  => 'گؤنئی آذربایجان',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'az',
				'iso_639_2'    => 'aze',
				'wp_locale'    => 'azb',
				'http_name'    => 'az',
				'priority'     => 1,
			),
			'az-tr' => array (
				'english_name' => 'Azerbaijani (Turkey)',
				'native_name'  => 'Azərbaycan Türkcəsi',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'az',
				'iso_639_2'    => 'aze',
				'wp_locale'    => 'az_TR',
				'http_name'    => 'az-TR',
				'priority'     => 1,
			),
			'ba'    => array (
				'english_name' => 'Bashkir',
				'native_name'  => 'башҡорт теле',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ba',
				'iso_639_2'    => 'bak',
				'wp_locale'    => 'ba',
				'http_name'    => 'ba',
				'priority'     => 1,
			),
			'bal'   => array (
				'english_name' => 'Catalan (Balear)',
				'native_name'  => 'Català (Balear)',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ca',
				'iso_639_2'    => 'cat',
				'wp_locale'    => 'bal',
				'http_name'    => 'ca',
				'priority'     => 1,
			),
			'bel'   => array (
				'english_name' => 'Belarusian',
				'native_name'  => 'Беларуская мова',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'be',
				'iso_639_2'    => 'bel',
				'wp_locale'    => 'bel',
				'http_name'    => 'be-BY',
				'priority'     => 1,
			),
			'bg'    => array (
				'english_name' => 'Bulgarian',
				'native_name'  => 'Български',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bg',
				'iso_639_2'    => 'bul',
				'wp_locale'    => 'bg_BG',
				'http_name'    => 'bg-BG',
				'priority'     => 1,
			),
			'bh'    => array (
				'english_name' => 'Bihari',
				'native_name'  => 'भोजपुरी',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bh',
				'iso_639_2'    => 'bih',
				'wp_locale'    => '',
				'http_name'    => 'bh',
				'priority'     => 1,
			),
			'bi'    => array (
				'english_name' => 'Bislama',
				'native_name'  => 'Bislama',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bi',
				'iso_639_2'    => 'bis',
				'wp_locale'    => '',
				'http_name'    => 'bi',
				'priority'     => 1,
			),
			'bm'    => array (
				'english_name' => 'Bambara',
				'native_name'  => 'Bamanankan',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bm',
				'iso_639_2'    => 'bam',
				'wp_locale'    => '',
				'http_name'    => 'bm',
				'priority'     => 1,
			),
			'bn'    => array (
				'english_name' => 'Bengali',
				'native_name'  => 'বাংলা',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bn',
				'iso_639_2'    => 'ben',
				'wp_locale'    => 'bn_BD',
				'http_name'    => 'bn-BD',
				'priority'     => 1,
			),
			'bo'    => array (
				'english_name' => 'Tibetan',
				'native_name'  => 'བོད་སྐད',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bo',
				'iso_639_2'    => 'bod',
				'wp_locale'    => 'bo',
				'http_name'    => 'bo',
				'priority'     => 1,
			),
			'br'    => array (
				'english_name' => 'Breton',
				'native_name'  => 'brezhoneg',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'br',
				'iso_639_2'    => 'bre',
				'wp_locale'    => '',
				'http_name'    => 'br',
				'priority'     => 1,
			),
			'bs'    => array (
				'english_name' => 'Bosnian',
				'native_name'  => 'Bosanski',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'bs',
				'iso_639_2'    => 'bos',
				'wp_locale'    => 'bs_BA',
				'http_name'    => 'bs-BA',
				'priority'     => 1,
			),
			'ca'    => array (
				'english_name' => 'Catalan',
				'native_name'  => 'Català',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ca',
				'iso_639_2'    => 'cat',
				'wp_locale'    => 'ca',
				'http_name'    => 'ca-ES',
				'priority'     => 1,
			),
			'ce'    => array (
				'english_name' => 'Chechen',
				'native_name'  => 'Нохчийн мотт',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ce',
				'iso_639_2'    => 'che',
				'wp_locale'    => '',
				'http_name'    => 'ce',
				'priority'     => 1,
			),
			'ch'    => array (
				'english_name' => 'Chamorro',
				'native_name'  => 'Chamoru',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ch',
				'iso_639_2'    => 'cha',
				'wp_locale'    => '',
				'http_name'    => 'ch',
				'priority'     => 1,
			),
			'ckb'   => array (
				'english_name' => 'Kurdish (Sorani)',
				'native_name'  => 'كوردی‎',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ku',
				'iso_639_2'    => 'kur',
				'wp_locale'    => 'ckb',
				'http_name'    => 'ku',
				'priority'     => 1,
			),
			'co'    => array (
				'english_name' => 'Corsican',
				'native_name'  => 'corsu',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'co',
				'iso_639_2'    => 'cos',
				'wp_locale'    => 'co',
				'http_name'    => 'co',
				'priority'     => 1,
			),
			'cr'    => array (
				'english_name' => 'Cree',
				'native_name'  => 'ᓀᐦᐃᔭᐍᐏᐣ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'cr',
				'iso_639_2'    => 'cre',
				'wp_locale'    => '',
				'http_name'    => 'cr',
				'priority'     => 1,
			),
			'cs'    => array (
				'english_name' => 'Czech',
				'native_name'  => 'čeština‎',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'cs',
				'iso_639_2'    => 'cze',
				'wp_locale'    => 'cs_CZ',
				'http_name'    => 'cs-CZ',
				'priority'     => 1,
			),
			'csb'   => array (
				'english_name' => 'Kashubian',
				'native_name'  => 'Kaszëbsczi',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => 'csb',
				'wp_locale'    => '',
				'http_name'    => 'csb',
				'priority'     => 1,
			),
			'cu'    => array (
				'english_name' => 'Church Slavic',
				'native_name'  => 'ѩзыкъ словѣньскъ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'cu',
				'iso_639_2'    => 'chu',
				'wp_locale'    => '',
				'http_name'    => 'cu',
				'priority'     => 1,
			),
			'cv'    => array (
				'english_name' => 'Chuvash',
				'native_name'  => 'чӑваш чӗлхи',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'cv',
				'iso_639_2'    => 'chv',
				'wp_locale'    => '',
				'http_name'    => 'cv',
				'priority'     => 1,
			),
			'cy'    => array (
				'english_name' => 'Welsh',
				'native_name'  => 'Cymraeg',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'cy',
				'iso_639_2'    => 'cym',
				'wp_locale'    => 'cy',
				'http_name'    => 'cy-GB',
				'priority'     => 1,
			),
			'da'    => array (
				'english_name' => 'Danish',
				'native_name'  => 'Dansk',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'da',
				'iso_639_2'    => 'dan',
				'wp_locale'    => 'da_DK',
				'http_name'    => 'da-DK',
				'priority'     => 1,
			),
			'de'    => array (
				'english_name' => 'German',
				'native_name'  => 'Deutsch',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'de',
				'iso_639_2'    => 'deu',
				'wp_locale'    => 'de_DE',
				'http_name'    => 'de-DE',
				'priority'     => 1,
			),
			'dv'    => array (
				'english_name' => 'Divehi',
				'native_name'  => 'ދިވެހި',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'dv',
				'iso_639_2'    => 'div',
				'wp_locale'    => 'dv',
				'http_name'    => 'dv',
				'priority'     => 1,
			),
			'dz'    => array (
				'english_name' => 'Dzongkha',
				'native_name'  => 'རྫོང་ཁ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'dz',
				'iso_639_2'    => 'dzo',
				'wp_locale'    => '',
				'http_name'    => 'dz',
				'priority'     => 1,
			),
			'ee'    => array (
				'english_name' => 'Ewe',
				'native_name'  => 'Eʋegbe',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ee',
				'iso_639_2'    => 'ewe',
				'wp_locale'    => '',
				'http_name'    => 'ee',
				'priority'     => 1,
			),
			'el-po' => array (
				'english_name' => 'Greek (Polytonic)',
				'native_name'  => 'Greek (Polytonic)',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => 'grc',
				'wp_locale'    => '',
				'http_name'    => 'grc',
				'priority'     => 1,
			),
			'el'    => array (
				'english_name' => 'Greek',
				'native_name'  => 'Ελληνικά',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'el',
				'iso_639_2'    => 'ell',
				'wp_locale'    => 'el',
				'http_name'    => 'el-GR',
				'priority'     => 1,
			),
			'en'    => array (
				'english_name' => 'English',
				'native_name'  => 'English',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'en',
				'iso_639_2'    => 'eng',
				'wp_locale'    => 'en_US',
				'http_name'    => 'en-US',
				'priority'     => 1,
			),
			'en-au' => array (
				'english_name' => 'English (Australia)',
				'native_name'  => 'English (Australia)',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'en',
				'iso_639_2'    => 'eng',
				'wp_locale'    => 'en_AU',
				'http_name'    => 'en-AU',
				'priority'     => 1,
			),
			'en-ca' => array (
				'english_name' => 'English (Canada)',
				'native_name'  => 'English (Canada)',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'en',
				'iso_639_2'    => 'eng',
				'wp_locale'    => 'en_CA',
				'http_name'    => 'en-CA',
				'priority'     => 1,
			),
			'en-gb' => array (
				'english_name' => 'English (UK)',
				'native_name'  => 'English (UK)',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'en',
				'iso_639_2'    => 'eng',
				'wp_locale'    => 'en_GB',
				'http_name'    => 'en-GB',
				'priority'     => 1,
			),
			'eo'    => array (
				'english_name' => 'Esperanto',
				'native_name'  => 'Esperanto',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'eo',
				'iso_639_2'    => 'epo',
				'wp_locale'    => 'eo',
				'http_name'    => 'eo-EO',
				'priority'     => 1,
			),
			'es-cl' => array (
				'english_name' => 'Spanish (Chile)',
				'native_name'  => 'Español de Chile',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_CL',
				'http_name'    => 'es-CL',
				'priority'     => 1,
			),
			'es-mx' => array (
				'english_name' => 'Spanish (Mexico)',
				'native_name'  => 'Español de México',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_MX',
				'http_name'    => 'es-MX',
				'priority'     => 1,
			),
			'es-pe' => array (
				'english_name' => 'Spanish (Peru)',
				'native_name'  => 'Español de Perú',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_PE',
				'http_name'    => 'es-PE',
				'priority'     => 1,
			),
			'es-pr' => array (
				'english_name' => 'Spanish (Puerto Rico)',
				'native_name'  => 'Español de Puerto Rico',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_PR',
				'http_name'    => 'es-PR',
				'priority'     => 1,
			),
			'es-ve' => array (
				'english_name' => 'Spanish (Venezuela)',
				'native_name'  => 'Español de Venezuela',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_VE',
				'http_name'    => 'es-VE',
				'priority'     => 1,
			),
			'es-co' => array (
				'english_name' => 'Spanish (Colombia)',
				'native_name'  => 'Español de Colombia',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_CO',
				'http_name'    => 'es-CO',
				'priority'     => 1,
			),
			'es'    => array (
				'english_name' => 'Spanish (Spain)',
				'native_name'  => 'Español',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'es',
				'iso_639_2'    => 'spa',
				'wp_locale'    => 'es_ES',
				'http_name'    => 'es-ES',
				'priority'     => 1,
			),
			'et'    => array (
				'english_name' => 'Estonian',
				'native_name'  => 'Eesti',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'et',
				'iso_639_2'    => 'est',
				'wp_locale'    => 'et',
				'http_name'    => 'et-EE',
				'priority'     => 1,
			),
			'eu'    => array (
				'english_name' => 'Basque',
				'native_name'  => 'Euskara',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'eu',
				'iso_639_2'    => 'eus',
				'wp_locale'    => 'eu',
				'http_name'    => 'eu-ES',
				'priority'     => 1,
			),
			'fa'    => array (
				'english_name' => 'Persian',
				'native_name'  => 'فارسی',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'fa',
				'iso_639_2'    => 'fas',
				'wp_locale'    => 'fa_IR',
				'http_name'    => 'fa-IR',
				'priority'     => 1,
			),
			'fa-af' => array (
				'english_name' => 'Persian (Afghanistan)',
				'native_name'  => '(فارسی (افغانستان',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'fa',
				'iso_639_2'    => 'eus',
				'wp_locale'    => 'fa_AF',
				'http_name'    => 'fa-AF',
				'priority'     => 1,
			),
			'fi'    => array (
				'english_name' => 'Finnish',
				'native_name'  => 'Suomi',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fi',
				'iso_639_2'    => 'fin',
				'wp_locale'    => 'fi',
				'http_name'    => 'fi-FI',
				'priority'     => 1,
			),
			'fj'    => array (
				'english_name' => 'Fijian',
				'native_name'  => 'vosa Vakaviti',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fj',
				'iso_639_2'    => 'fij',
				'wp_locale'    => '',
				'http_name'    => 'fj',
				'priority'     => 1,
			),
			'fo'    => array (
				'english_name' => 'Faroese',
				'native_name'  => 'føroyskt',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fo',
				'iso_639_2'    => 'fao',
				'wp_locale'    => 'fo',
				'http_name'    => 'fo-FO',
				'priority'     => 1,
			),
			'fr'    => array (
				'english_name' => 'French (France)',
				'native_name'  => 'Français',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fr',
				'iso_639_2'    => 'fra',
				'wp_locale'    => 'fr_FR',
				'http_name'    => 'fr-FR',
				'priority'     => 1,
			),
			'fr-be' => array (
				'english_name' => 'French (Belgium)',
				'native_name'  => 'Français de Belgique',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fr',
				'iso_639_2'    => 'fra',
				'wp_locale'    => 'fr_BE',
				'http_name'    => 'fr-BE',
				'priority'     => 1,
			),
			'fr-ca' => array (
				'english_name' => 'French (Canada)',
				'native_name'  => 'Français du Canada',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fr',
				'iso_639_2'    => 'fra',
				'wp_locale'    => '',
				'http_name'    => 'fr-CA',
				'priority'     => 1,
			),
			'fr-ch' => array (
				'english_name' => 'French (Switzerland)',
				'native_name'  => 'Français de Suisse',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fr',
				'iso_639_2'    => 'fra',
				'wp_locale'    => '',
				'http_name'    => 'fr',
				'priority'     => 1,
			),
			'fy'    => array (
				'english_name' => 'Frisian',
				'native_name'  => 'Frysk',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'fy',
				'iso_639_2'    => 'fry',
				'wp_locale'    => 'fy',
				'http_name'    => 'fy-NL',
				'priority'     => 1,
			),
			'ga'    => array (
				'english_name' => 'Irish',
				'native_name'  => 'Gaelige',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ga',
				'iso_639_2'    => 'gle',
				'wp_locale'    => '',
				'http_name'    => 'ga-IE',
				'priority'     => 1,
			),
			'gd'    => array (
				'english_name' => 'Scottish Gaelic',
				'native_name'  => 'Gàidhlig',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'gd',
				'iso_639_2'    => '',
				'wp_locale'    => 'gd',
				'http_name'    => 'gd',
				'priority'     => 1,
			),
			'gl'    => array (
				'english_name' => 'Galician',
				'native_name'  => 'Galego',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'gl',
				'iso_639_2'    => '',
				'wp_locale'    => 'gl_ES',
				'http_name'    => 'gl-ES',
				'priority'     => 1,
			),
			'gn'    => array (
				'english_name' => 'Guaraní',
				'native_name'  => 'Avañe’ẽ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'gn',
				'iso_639_2'    => '',
				'wp_locale'    => 'gn',
				'http_name'    => 'gn',
				'priority'     => 1,
			),
			'gsw'   => array (
				'english_name' => 'Swiss German',
				'native_name'  => 'Schwyzerdütsch',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'gsw',
				'http_name'    => '',
				'priority'     => 1,
			),
			'gu'    => array (
				'english_name' => 'Gujarati',
				'native_name'  => 'ગુજરાતી',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'gu',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'gu',
				'priority'     => 1,
			),
			'ha'    => array (
				'english_name' => 'Hausa',
				'native_name'  => 'هَوُسَ',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'he',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'he',
				'priority'     => 1,
			),
			'haw'   => array (
				'english_name' => 'Hawaiian',
				'native_name'  => 'Ōlelo Hawaiʻi',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'haw_US',
				'http_name'    => 'haw-US',
				'priority'     => 1,
			),
			'haz'   => array (
				'english_name' => 'Hazaragi',
				'native_name'  => 'هزاره گی',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'haz',
				'http_name'    => '',
				'priority'     => 1,
			),
			'he'    => array (
				'english_name' => 'Hebrew',
				'native_name'  => 'עִבְרִית',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'he',
				'iso_639_2'    => '',
				'wp_locale'    => 'he_IL',
				'http_name'    => 'he-IL',
				'priority'     => 1,
			),
			'hi'    => array (
				'english_name' => 'Hindi',
				'native_name'  => 'हिन्दी',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'hi',
				'iso_639_2'    => '',
				'wp_locale'    => 'hi_IN',
				'http_name'    => 'hi-IN',
				'priority'     => 1,
			),
			'hr'    => array (
				'english_name' => 'Croatian',
				'native_name'  => 'Hrvatski',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'hr',
				'iso_639_2'    => '',
				'wp_locale'    => 'hr',
				'http_name'    => 'hr-HR',
				'priority'     => 1,
			),
			'hu'    => array (
				'english_name' => 'Hungarian',
				'native_name'  => 'Magyar',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'hu',
				'iso_639_2'    => '',
				'wp_locale'    => 'hu_HU',
				'http_name'    => 'hu-HU',
				'priority'     => 1,
			),
			'hy'    => array (
				'english_name' => 'Armenian',
				'native_name'  => 'Հայերեն',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'hy',
				'iso_639_2'    => '',
				'wp_locale'    => 'hy',
				'http_name'    => 'hy-AM',
				'priority'     => 1,
			),
			'ia'    => array (
				'english_name' => 'Interlingua',
				'native_name'  => 'Interlingua',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ia',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'ia',
				'priority'     => 1,
			),
			'id'    => array (
				'english_name' => 'Indonesian',
				'native_name'  => 'Bahasa Indonesia',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'id',
				'iso_639_2'    => '',
				'wp_locale'    => 'id_ID',
				'http_name'    => 'id-ID',
				'priority'     => 1,
			),
			'ike'   => array (
				'english_name' => 'Inuktitut',
				'native_name'  => 'ᐃᓄᒃᑎᑐᑦ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'iu',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'iu',
				'priority'     => 1,
			),
			'ilo'   => array (
				'english_name' => 'Iloko',
				'native_name'  => 'Pagsasao nga Iloko',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'is'    => array (
				'english_name' => 'Icelandic',
				'native_name'  => 'Íslenska',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'is',
				'iso_639_2'    => '',
				'wp_locale'    => 'is_IS',
				'http_name'    => 'is-IS',
				'priority'     => 1,
			),
			'it'    => array (
				'english_name' => 'Italian',
				'native_name'  => 'Italiano',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'it',
				'iso_639_2'    => '',
				'wp_locale'    => 'it_IT',
				'http_name'    => 'it-IT',
				'priority'     => 1,
			),
			'ja'    => array (
				'english_name' => 'Japanese',
				'native_name'  => '日本語',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ja',
				'iso_639_2'    => '',
				'wp_locale'    => 'ja',
				'http_name'    => 'ja-JP',
				'priority'     => 1,
			),
			'jv'    => array (
				'english_name' => 'Javanese',
				'native_name'  => 'Basa Jawa',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'jv',
				'iso_639_2'    => '',
				'wp_locale'    => 'jv_ID',
				'http_name'    => 'jv-ID',
				'priority'     => 1,
			),
			'ka'    => array (
				'english_name' => 'Georgian',
				'native_name'  => 'ქართული',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ka',
				'iso_639_2'    => '',
				'wp_locale'    => 'ka_GE',
				'http_name'    => 'ka-GE',
				'priority'     => 1,
			),
			'rw'    => array (
				'english_name' => 'Kinyarwanda',
				'native_name'  => 'Kinyarwanda',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'rw',
				'iso_639_2'    => '',
				'wp_locale'    => 'kin',
				'http_name'    => 'rw',
				'priority'     => 1,
			),
			'kk'    => array (
				'english_name' => 'Kazakh',
				'native_name'  => 'Қазақ тілі',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'kk',
				'iso_639_2'    => '',
				'wp_locale'    => 'kk',
				'http_name'    => 'kk',
				'priority'     => 1,
			),
			'km'    => array (
				'english_name' => 'Khmer',
				'native_name'  => 'ភាសាខ្មែរ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'km',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'km-KH',
				'priority'     => 1,
			),
			'kn'    => array (
				'english_name' => 'Kannada',
				'native_name'  => 'ಕನ್ನಡ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'kn',
				'iso_639_2'    => '',
				'wp_locale'    => 'kn',
				'http_name'    => 'kn',
				'priority'     => 1,
			),
			'ko'    => array (
				'english_name' => 'Korean',
				'native_name'  => '한국어',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ko',
				'iso_639_2'    => '',
				'wp_locale'    => 'ko_KR',
				'http_name'    => 'ko-KR',
				'priority'     => 1,
			),
			'ks'    => array (
				'english_name' => 'Kashmiri',
				'native_name'  => 'कश्मीरी',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ks',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'ks',
				'priority'     => 1,
			),
			'ku'    => array (
				'english_name' => 'Kurdish (Kurmanji)',
				'native_name'  => 'Kurdî',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ku',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'ku-TR',
				'priority'     => 1,
			),
			'ky'    => array (
				'english_name' => 'Kirghiz',
				'native_name'  => 'кыргыз тили',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ky',
				'iso_639_2'    => '',
				'wp_locale'    => 'ky_KY',
				'http_name'    => 'ky-KY',
				'priority'     => 1,
			),
			'la'    => array (
				'english_name' => 'Latin',
				'native_name'  => 'latine',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'la',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'la-VA',
				'priority'     => 1,
			),
			'lb'    => array (
				'english_name' => 'Luxembourgish',
				'native_name'  => 'Lëtzebuergesch',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'lb',
				'iso_639_2'    => '',
				'wp_locale'    => 'lb_LU',
				'http_name'    => 'lb-LU',
				'priority'     => 1,
			),
			'li'    => array (
				'english_name' => 'Limburgish',
				'native_name'  => 'Limburgs',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'li',
				'iso_639_2'    => '',
				'wp_locale'    => 'li',
				'http_name'    => 'li',
				'priority'     => 1,
			),
			'lo'    => array (
				'english_name' => 'Lao',
				'native_name'  => 'ພາສາລາວ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'lo',
				'iso_639_2'    => '',
				'wp_locale'    => 'lo',
				'http_name'    => 'lo',
				'priority'     => 1,
			),
			'lt'    => array (
				'english_name' => 'Lithuanian',
				'native_name'  => 'Lietuvių kalba',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'lt',
				'iso_639_2'    => '',
				'wp_locale'    => 'lt_LT',
				'http_name'    => 'lt-LT',
				'priority'     => 1,
			),
			'lv'    => array (
				'english_name' => 'Latvian',
				'native_name'  => 'latviešu valoda',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'lv',
				'iso_639_2'    => '',
				'wp_locale'    => 'lv',
				'http_name'    => 'lv-LV',
				'priority'     => 1,
			),
			'me'    => array (
				'english_name' => 'Montenegrin',
				'native_name'  => 'Crnogorski jezik',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'me',
				'iso_639_2'    => '',
				'wp_locale'    => 'me_ME',
				'http_name'    => 'me-ME',
				'priority'     => 1,
			),
			'mg'    => array (
				'english_name' => 'Malagasy',
				'native_name'  => 'Malagasy',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'mg',
				'iso_639_2'    => '',
				'wp_locale'    => 'mg_MG',
				'http_name'    => 'mg-MG',
				'priority'     => 1,
			),
			'mhr'   => array (
				'english_name' => 'Mari (Meadow)',
				'native_name'  => 'олык марий',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'mk'    => array (
				'english_name' => 'Macedonian',
				'native_name'  => 'македонски јазик',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'mk',
				'iso_639_2'    => '',
				'wp_locale'    => 'mk_MK',
				'http_name'    => 'mk-MK',
				'priority'     => 1,
			),
			'ml'    => array (
				'english_name' => 'Malayalam',
				'native_name'  => 'മലയാളം',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ml',
				'iso_639_2'    => '',
				'wp_locale'    => 'ml_IN',
				'http_name'    => 'ml-IN',
				'priority'     => 1,
			),
			'mn'    => array (
				'english_name' => 'Mongolian',
				'native_name'  => 'Монгол',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'mn',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'mn',
				'priority'     => 1,
			),
			'mr'    => array (
				'english_name' => 'Marathi',
				'native_name'  => 'मराठी',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'mr',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'mr',
				'priority'     => 1,
			),
			'mri'   => array (
				'english_name' => 'Maori',
				'native_name'  => 'Te Reo Māori',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'mrj'   => array (
				'english_name' => 'Mari (Hill)',
				'native_name'  => 'кырык мары',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'ms'    => array (
				'english_name' => 'Malay',
				'native_name'  => 'Bahasa Melayu',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ms',
				'iso_639_2'    => '',
				'wp_locale'    => 'ms_MY',
				'http_name'    => 'ms-MY',
				'priority'     => 1,
			),
			'mwl'   => array (
				'english_name' => 'Mirandese',
				'native_name'  => 'Mirandés',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'mya'   => array (
				'english_name' => 'Burmese',
				'native_name'  => 'ဗမာစာ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'my',
				'iso_639_2'    => '',
				'wp_locale'    => 'my_MM',
				'http_name'    => 'my-MM',
				'priority'     => 1,
			),
			'ne'    => array (
				'english_name' => 'Nepali',
				'native_name'  => 'नेपाली',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ne',
				'iso_639_2'    => '',
				'wp_locale'    => 'ne_NP',
				'http_name'    => 'ne-NP',
				'priority'     => 1,
			),
			'nb'    => array (
				'english_name' => 'Norwegian (Bokmål)',
				'native_name'  => 'Norsk bokmål',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'nb',
				'iso_639_2'    => '',
				'wp_locale'    => 'nb_NO',
				'http_name'    => 'nb-NO',
				'priority'     => 1,
			),
			'nl'    => array (
				'english_name' => 'Dutch',
				'native_name'  => 'Nederlands',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'nl',
				'iso_639_2'    => '',
				'wp_locale'    => 'nl_NL',
				'http_name'    => 'nl-NL',
				'priority'     => 1,
			),
			'nl-be' => array (
				'english_name' => 'Dutch (Belgium)',
				'native_name'  => 'Nederlands (België)',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'nl',
				'iso_639_2'    => '',
				'wp_locale'    => 'nl_BE',
				'http_name'    => 'nl-BE',
				'priority'     => 1,
			),
			'nn'    => array (
				'english_name' => 'Norwegian (Nynorsk)',
				'native_name'  => 'Norsk nynorsk',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'nn',
				'iso_639_2'    => '',
				'wp_locale'    => 'nn_NO',
				'http_name'    => 'nn-NO',
				'priority'     => 1,
			),
			'no'    => array (
				'english_name' => 'Norwegian',
				'native_name'  => 'Norsk',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'no',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'no',
				'priority'     => 1,
			),
			'oc'    => array (
				'english_name' => 'Occitan',
				'native_name'  => 'Occitan',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'oc',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'oc',
				'priority'     => 1,
			),
			'os'    => array (
				'english_name' => 'Ossetic',
				'native_name'  => 'Ирон',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'os',
				'iso_639_2'    => '',
				'wp_locale'    => 'os',
				'http_name'    => 'os',
				'priority'     => 1,
			),
			'pa'    => array (
				'english_name' => 'Punjabi',
				'native_name'  => 'ਪੰਜਾਬੀ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'pa',
				'iso_639_2'    => '',
				'wp_locale'    => 'pa_IN',
				'http_name'    => 'pa-IN',
				'priority'     => 1,
			),
			'pl'    => array (
				'english_name' => 'Polish',
				'native_name'  => 'Polski',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'pl',
				'iso_639_2'    => '',
				'wp_locale'    => 'pl_PL',
				'http_name'    => 'pl-PL',
				'priority'     => 1,
			),
			'pt-br' => array (
				'english_name' => 'Portuguese (Brazil)',
				'native_name'  => 'Português do Brasil',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'pt',
				'iso_639_2'    => '',
				'wp_locale'    => 'pt_BR',
				'http_name'    => 'pt-BR',
				'priority'     => 1,
			),
			'pt'    => array (
				'english_name' => 'Portuguese (Portugal)',
				'native_name'  => 'Português',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'pt',
				'iso_639_2'    => '',
				'wp_locale'    => 'pt_PT',
				'http_name'    => 'pt-PT',
				'priority'     => 1,
			),
			'ps'    => array (
				'english_name' => 'Pashto',
				'native_name'  => 'پښتو',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'ps',
				'iso_639_2'    => '',
				'wp_locale'    => 'ps',
				'http_name'    => 'ps-AF',
				'priority'     => 1,
			),
			'ro'    => array (
				'english_name' => 'Romanian',
				'native_name'  => 'Română',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ro',
				'iso_639_2'    => '',
				'wp_locale'    => 'ro_RO',
				'http_name'    => 'ro-RO',
				'priority'     => 1,
			),
			'ru'    => array (
				'english_name' => 'Russian',
				'native_name'  => 'Русский',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ru',
				'iso_639_2'    => '',
				'wp_locale'    => 'ru_RU',
				'http_name'    => 'ru-RU',
				'priority'     => 1,
			),
			'ru-ua' => array (
				'english_name' => 'Russian (Ukraine)',
				'native_name'  => 'украї́нська мо́ва',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ru',
				'iso_639_2'    => '',
				'wp_locale'    => 'ru_UA',
				'http_name'    => 'ru-UA',
				'priority'     => 1,
			),
			'rue'   => array (
				'english_name' => 'Rusyn',
				'native_name'  => 'Русиньскый',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'rue',
				'http_name'    => '',
				'priority'     => 1,
			),
			'rup'   => array (
				'english_name' => 'Aromanian',
				'native_name'  => 'Armãneashce',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'rup_MK',
				'http_name'    => 'rup-MK',
				'priority'     => 1,
			),
			'sah'   => array (
				'english_name' => 'Sakha',
				'native_name'  => 'Sakha',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'sah',
				'http_name'    => '',
				'priority'     => 1,
			),
			'sa-in' => array (
				'english_name' => 'Sanskrit',
				'native_name'  => 'भारतम्',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'sa_IN',
				'http_name'    => 'sa-IN',
				'priority'     => 1,
			),
			'sd'    => array (
				'english_name' => 'Sindhi',
				'native_name'  => 'سندھ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sd',
				'iso_639_2'    => '',
				'wp_locale'    => 'sd_PK',
				'http_name'    => 'sd-PK',
				'priority'     => 1,
			),
			'si'    => array (
				'english_name' => 'Sinhala',
				'native_name'  => 'සිංහල',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'si',
				'iso_639_2'    => '',
				'wp_locale'    => 'si_LK',
				'http_name'    => 'si-LK',
				'priority'     => 1,
			),
			'sk'    => array (
				'english_name' => 'Slovak',
				'native_name'  => 'Slovenčina',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sk',
				'iso_639_2'    => '',
				'wp_locale'    => 'sk_SK',
				'http_name'    => 'sk-SK',
				'priority'     => 1,
			),
			'sl'    => array (
				'english_name' => 'Slovenian',
				'native_name'  => 'slovenščina',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sl',
				'iso_639_2'    => '',
				'wp_locale'    => 'sl_SI',
				'http_name'    => 'sl-SI',
				'priority'     => 1,
			),
			'so'    => array (
				'english_name' => 'Somali',
				'native_name'  => 'Afsoomaali',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'so',
				'iso_639_2'    => '',
				'wp_locale'    => 'so_SO',
				'http_name'    => 'so-SO',
				'priority'     => 1,
			),
			'sq'    => array (
				'english_name' => 'Albanian',
				'native_name'  => 'Shqip',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sq',
				'iso_639_2'    => '',
				'wp_locale'    => 'sq',
				'http_name'    => 'sq-AL',
				'priority'     => 1,
			),
			'sr'    => array (
				'english_name' => 'Serbian',
				'native_name'  => 'Српски језик',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sr',
				'iso_639_2'    => '',
				'wp_locale'    => 'sr_RS',
				'http_name'    => 'sr-RS',
				'priority'     => 1,
			),
			'srd'   => array (
				'english_name' => 'Sardinian',
				'native_name'  => 'sardu',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sc',
				'iso_639_2'    => '',
				'wp_locale'    => 'srd',
				'http_name'    => 'sc',
				'priority'     => 1,
			),
			'su'    => array (
				'english_name' => 'Sundanese',
				'native_name'  => 'Basa Sunda',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'su',
				'iso_639_2'    => '',
				'wp_locale'    => 'su_ID',
				'http_name'    => 'su-ID',
				'priority'     => 1,
			),
			'sv'    => array (
				'english_name' => 'Swedish',
				'native_name'  => 'Svenska',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sv',
				'iso_639_2'    => '',
				'wp_locale'    => 'sv_SE',
				'http_name'    => 'sv-SE',
				'priority'     => 1,
			),
			'sw'    => array (
				'english_name' => 'Swahili',
				'native_name'  => 'Kiswahili',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'sw',
				'iso_639_2'    => '',
				'wp_locale'    => 'sw',
				'http_name'    => 'sw-KE',
				'priority'     => 1,
			),
			'ta'    => array (
				'english_name' => 'Tamil',
				'native_name'  => 'தமிழ்',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ta',
				'iso_639_2'    => '',
				'wp_locale'    => 'ta_IN',
				'http_name'    => 'ta-IN',
				'priority'     => 1,
			),
			'ta-lk' => array (
				'english_name' => 'Tamil (Sri Lanka)',
				'native_name'  => 'தமிழ்',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ta',
				'iso_639_2'    => '',
				'wp_locale'    => 'ta_LK',
				'http_name'    => 'ta-LK',
				'priority'     => 1,
			),
			'te'    => array (
				'english_name' => 'Telugu',
				'native_name'  => 'తెలుగు',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'te',
				'iso_639_2'    => '',
				'wp_locale'    => 'te',
				'http_name'    => 'te-IN',
				'priority'     => 1,
			),
			'tg'    => array (
				'english_name' => 'Tajik',
				'native_name'  => 'тоҷикӣ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'tg',
				'iso_639_2'    => '',
				'wp_locale'    => 'tg',
				'http_name'    => 'tg',
				'priority'     => 1,
			),
			'th'    => array (
				'english_name' => 'Thai',
				'native_name'  => 'ไทย',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'th',
				'iso_639_2'    => '',
				'wp_locale'    => 'th',
				'http_name'    => 'th-TH',
				'priority'     => 1,
			),
			'tlh'   => array (
				'english_name' => 'Klingon',
				'native_name'  => 'TlhIngan',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'tlh',
				'http_name'    => 'tlh',
				'priority'     => 1,
			),
			'tl'    => array (
				'english_name' => 'Tagalog',
				'native_name'  => 'Tagalog',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'tl',
				'iso_639_2'    => '',
				'wp_locale'    => 'tl',
				'http_name'    => 'tl-PH',
				'priority'     => 1,
			),
			'tr'    => array (
				'english_name' => 'Turkish',
				'native_name'  => 'Türkçe',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'tr',
				'iso_639_2'    => '',
				'wp_locale'    => 'tr_TR',
				'http_name'    => 'tr-TR',
				'priority'     => 1,
			),
			'tt'    => array (
				'english_name' => 'Tatar',
				'native_name'  => 'Татар теле',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'tt',
				'iso_639_2'    => '',
				'wp_locale'    => 'tt_RU',
				'http_name'    => 'tt-RU',
				'priority'     => 1,
			),
			'tuk'   => array (
				'english_name' => 'Turkmen',
				'native_name'  => 'Türkmençe',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'tk',
				'iso_639_2'    => '',
				'wp_locale'    => 'tuk',
				'http_name'    => 'tk',
				'priority'     => 1,
			),
			'tzm'   => array (
				'english_name' => 'Tamazight (Central Atlas)',
				'native_name'  => 'ⵜⴰⵎⴰⵣⵉⵖⵜ',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'tzm',
				'http_name'    => '',
				'priority'     => 1,
			),
			'udm'   => array (
				'english_name' => 'Udmurt',
				'native_name'  => 'удмурт кыл',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'ug'    => array (
				'english_name' => 'Uighur',
				'native_name'  => 'Uyƣurqə',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ug',
				'iso_639_2'    => '',
				'wp_locale'    => 'ug_CN',
				'http_name'    => 'ug-CN',
				'priority'     => 1,
			),
			'uk'    => array (
				'english_name' => 'Ukrainian',
				'native_name'  => 'Українська',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'uk',
				'iso_639_2'    => '',
				'wp_locale'    => 'uk',
				'http_name'    => 'uk-UA',
				'priority'     => 1,
			),
			'ur'    => array (
				'english_name' => 'Urdu',
				'native_name'  => 'اردو',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'ur',
				'iso_639_2'    => '',
				'wp_locale'    => 'ur',
				'http_name'    => 'ur',
				'priority'     => 1,
			),
			'uz'    => array (
				'english_name' => 'Uzbek',
				'native_name'  => 'O‘zbekcha',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'uz',
				'iso_639_2'    => '',
				'wp_locale'    => 'uz_UZ',
				'http_name'    => 'uz-UZ',
				'priority'     => 1,
			),
			'vec'   => array (
				'english_name' => 'Venetian',
				'native_name'  => 'vèneta',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => '',
				'priority'     => 1,
			),
			'vi'    => array (
				'english_name' => 'Vietnamese',
				'native_name'  => 'Tiếng Việt',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'vi',
				'iso_639_2'    => '',
				'wp_locale'    => 'vi',
				'http_name'    => 'vi-VN',
				'priority'     => 1,
			),
			'wa'    => array (
				'english_name' => 'Walloon',
				'native_name'  => 'Walon',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'wa',
				'iso_639_2'    => '',
				'wp_locale'    => 'wa',
				'http_name'    => 'wa',
				'priority'     => 1,
			),
			'xmf'   => array (
				'english_name' => 'Mingrelian',
				'native_name'  => 'მარგალური ნინა',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => '',
				'iso_639_2'    => '',
				'wp_locale'    => 'xmf',
				'http_name'    => '',
				'priority'     => 1,
			),
			'yi'    => array (
				'english_name' => 'Yiddish',
				'native_name'  => 'ייִדיש',
				'custom_name'  => '',
				'is_rtl'       => 1,
				'iso_639_1'    => 'yi',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'yi',
				'priority'     => 1,
			),
			'yo'    => array (
				'english_name' => 'Yorùbá',
				'native_name'  => 'èdè Yorùbá',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'yo',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'yo',
				'priority'     => 1,
			),
			'zh-cn' => array (
				'english_name' => 'Chinese (China)',
				'native_name'  => '中文',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'zh',
				'iso_639_2'    => '',
				'wp_locale'    => 'zh_CN',
				'http_name'    => 'zh-CN',
				'priority'     => 1,
			),
			'zh-hk' => array (
				'english_name' => 'Chinese (Hong Kong)',
				'native_name'  => '香港中文版	',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'zh',
				'iso_639_2'    => '',
				'wp_locale'    => 'zh_HK',
				'http_name'    => 'zh-HK',
				'priority'     => 1,
			),
			'zh-sg' => array (
				'english_name' => 'Chinese (Singapore)',
				'native_name'  => '中文',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'zh',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'zh',
				'priority'     => 1,
			),
			'zh-tw' => array (
				'english_name' => 'Chinese (Taiwan)',
				'native_name'  => '中文',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'zh',
				'iso_639_2'    => '',
				'wp_locale'    => 'zh_TW',
				'http_name'    => 'zh-TW',
				'priority'     => 1,
			),
			'zh'    => array (
				'english_name' => 'Chinese',
				'native_name'  => '中文',
				'custom_name'  => '',
				'is_rtl'       => 0,
				'iso_639_1'    => 'zh',
				'iso_639_2'    => '',
				'wp_locale'    => '',
				'http_name'    => 'zh',
				'priority'     => 1,
			),
		);

		foreach ( $fields as $field )
			$out[ ] = "('" . join( "','", array_values( $field ) ) . "')";

		return join( ",", $out );
	}
}